==> haskell-tasty-silver-3.3.1.3-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-silver
version:              3.3.1.3
visibility:           public
id:                   tasty-silver-3.3.1.3-3U6EjG1OncaH2ZNbtw25aB
key:                  tasty-silver-3.3.1.3-3U6EjG1OncaH2ZNbtw25aB
license:              MIT
maintainer:           Philipp Hausmann, Andreas Abel
author:               Philipp Hausmann, Roman Cheplyaka and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  7e5f7adeb63d017d577108ceecb6192e
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-silver-3.3.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-silver-3.3.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.1.3-3U6EjG1OncaH2ZNbtw25aB
depends:
    ansi-terminal-0.11.4-76S2tDtyH9a6L7WbLmzQGB
    async-2.2.5-E2Nvh3WkFMk4pawohHisBC base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.17.1.0-HdCEVmKoTQ5GAljNy1HSZt
    process-1.6.16.0 process-extras-0.7.4-IMRvIQRh2L8LDz5jGFchi5
    regex-tdfa-1.3.2.2-KgUSVHm2u0lH0ZR7ak0qu7
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-4P9niUw2HXJLAdSnzQ3qYx
    temporary-1.3-FlaIcvUvn772mIGdBvv8bV text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-silver-3.3.1.3-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-silver
version:              3.3.1.3
visibility:           public
id:                   tasty-silver-3.3.1.3-IWeRe14HVS6JVwGsYjDUSq
key:                  tasty-silver-3.3.1.3-IWeRe14HVS6JVwGsYjDUSq
license:              MIT
maintainer:           Philipp Hausmann, Andreas Abel
author:               Philipp Hausmann, Roman Cheplyaka and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  2a326761c8f4599754ef6e81135598fc
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-silver-3.3.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-silver-3.3.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.1.3-IWeRe14HVS6JVwGsYjDUSq
depends:
    ansi-terminal-0.11.4-76S2tDtyH9a6L7WbLmzQGB
    async-2.2.5-E2Nvh3WkFMk4pawohHisBC base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.17.1.0-HdCEVmKoTQ5GAljNy1HSZt
    process-1.6.16.0 process-extras-0.7.4-IMRvIQRh2L8LDz5jGFchi5
    regex-tdfa-1.3.2.2-7T4dQxeDDSEFjrz9fGodBZ
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-4P9niUw2HXJLAdSnzQ3qYx
    temporary-1.3-FlaIcvUvn772mIGdBvv8bV text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
